import base64


class UnpaddedBase64Encoder(object):
    """
    A simple encoder class to encode/decode to base64 with the 'padding' (trailing equal characters) removed.

    This is needed for PyNaCL to be compatible with keys generated by the old ed25519 library.
    """

    @staticmethod
    def encode(data):
        return base64.b64encode(data).rstrip(b"=")

    @staticmethod
    def decode(data):
        # We need to add the padding back if it's been removed.
        # The correct type of the padding depends on what the input is,
        # as base64 (and the decoder in general) is happy to take in both bytes and unicode.

        if isinstance(data, bytes):
            padding = b"="
        else:
            padding = u"="

        data += padding * ((4 - len(data) % 4) % 4)

        return base64.b64decode(data)
